.. include:: ../README.rst


Developer documentation
=======================

.. toctree::
    :maxdepth: 2

    api.rst
    glossary.rst


.. include:: CHANGELOG.rst
.. include:: LICENSE.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

